==> rho-common-facade-1.0.0-sources.jar: cn/smarthse/rho/modules/sys/entity/s/SupervisionSupInfo.java <==
/*
 * Powered By [rapid-framework]
 * Web Site: http://www.rapid-framework.org.cn
 * Google Code: http://code.google.com/p/rapid-framework/
 * Since 2008 - 2024
 */


package cn.smarthse.rho.modules.sys.entity.s;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.annotations.ApiModel;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;


@ApiModel(value = "放射卫生监督信息 对象", description = "医院：放射卫生监督信息")
@TableName("supervision_sup_info")
@Data
public class SupervisionSupInfo implements Serializable {

    private static final long serialVersionUID = 1L;
    /**
     * ID
     */
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    private Long id;
    /**
     * 医院分院id
     */
    private Long mainCid;
    /**
     * 对应主院医院名称
     */
    private String compMainName;
    /**
     * 医院分院id
     */
    private Long cid;
    /**
     * 对应分院医院名称
     */
    private String compName;
    /**
     * 统一社会信用代码
     */
    private String creditCode;
    /**
     * 营业状态
     */
    private String jdYyzt;
    /**
     * 监督日期
     */
    private Date supervisionDate;
    /**
     * 监督任务类型
     */
    private String taskType;
    /**
     * 监督员1
     */
    private String supervisionPerson1;
    /**
     * 监督员2
     */
    private String supervisionPerson2;
    /**
     * 检查结果
     */
    private String yrdwJcjg;
    /**
     * 采取行为
     */
    private String cqxw;
    /**
     * 检查项
     */
    private String jcx;
    /**
     * 修改时间
     */
    private Date sourceUpdateTime;
    /**
     * 填报时间
     */
    private Date sourceCreateTime;
    /**
     * 监督执法机构
     */
    private String rorgname;
    /**
     * 原主键
     */
    private String sourceId;
    /**
     * 创建时间-数据同步时间
     */
    private Date createDate;
    /**
     * 最后修改时间-数据最后更新时间
     */
    private Date updateDate;

}

==> rho-common-facade-2.0.0-sources.jar: cn/smarthse/rho/modules/sys/entity/s/SupervisionSupInfo.java <==
/*
 * Powered By [rapid-framework]
 * Web Site: http://www.rapid-framework.org.cn
 * Google Code: http://code.google.com/p/rapid-framework/
 * Since 2008 - 2024
 */


package cn.smarthse.rho.modules.sys.entity.s;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;


//@ApiModel(value = "放射卫生监督信息 对象", description = "医院：放射卫生监督信息")
@TableName("supervision_sup_info")
@Data
public class SupervisionSupInfo implements Serializable {

    private static final long serialVersionUID = 1L;
    /**
     * ID
     */
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    private Long id;
    /**
     * 医院分院id
     */
    private Long mainCid;
    /**
     * 对应主院医院名称
     */
    private String compMainName;
    /**
     * 医院分院id
     */
    private Long cid;
    /**
     * 对应分院医院名称
     */
    private String compName;
    /**
     * 统一社会信用代码
     */
    private String creditCode;
    /**
     * 营业状态
     */
    private String jdYyzt;
    /**
     * 监督日期
     */
    private Date supervisionDate;
    /**
     * 监督任务类型
     */
    private String taskType;
    /**
     * 监督员1
     */
    private String supervisionPerson1;
    /**
     * 监督员2
     */
    private String supervisionPerson2;
    /**
     * 检查结果
     */
    private String yrdwJcjg;
    /**
     * 采取行为
     */
    private String cqxw;
    /**
     * 检查项
     */
    private String jcx;
    /**
     * 修改时间
     */
    private Date sourceUpdateTime;
    /**
     * 填报时间
     */
    private Date sourceCreateTime;
    /**
     * 监督执法机构
     */
    private String rorgname;
    /**
     * 原主键
     */
    private String sourceId;
    /**
     * 创建时间-数据同步时间
     */
    private Date createDate;
    /**
     * 最后修改时间-数据最后更新时间
     */
    private Date updateDate;

}
